pub struct LoadedImage<'a, Message, Theme, Renderer>where
Renderer: Renderer + Renderer,{
handle: <Renderer as Renderer>::Handle,
content: Element<'a, Message, Theme, Renderer>,
}Expand description
Forces the wrapped image to be loaded before drawing.
May cause a dropped frame if the image is not already in the cache. This is useful when you want to ensure an image is loaded before it is drawn, for example when swapping out a placeholder. Otherwise, the image may be blank until the next redraw.
Fields
handle: <Renderer as Renderer>::Handlecontent: Element<'a, Message, Theme, Renderer>Implementations
Sourceimpl<'a, Message, Theme, Renderer> LoadedImage<'a, Message, Theme, Renderer>where
Renderer: Renderer + Renderer,
<Renderer as Renderer>::Handle: 'a,
impl<'a, Message, Theme, Renderer> LoadedImage<'a, Message, Theme, Renderer>where
Renderer: Renderer + Renderer,
<Renderer as Renderer>::Handle: 'a,
Sourcepub(crate) fn new(handle: <Renderer as Renderer>::Handle) -> Self
pub(crate) fn new(handle: <Renderer as Renderer>::Handle) -> Self
Creates an empty LoadedImage.